@@ -12,11 +12,12 @@ require Exporter;
 @EXPORT_OK = qw(pd_raw %mtable %umult %wdays);
 
 use strict;
+#use diagnostics;
 
 # constants
 use vars qw(%mtable %umult %wdays $VERSION);
 
-$VERSION = 101.06_21_01;
+$VERSION = 2003.1125;
 
 # globals
 use vars qw($debug); 
@@ -76,7 +77,7 @@ sub parsedate
 	my $rel; 		# time&|date is relative
 
 	my $isspec;
-	my $now = $options{NOW} || time;
+	my $now = defined($options{NOW}) ? $options{NOW} : time;
 	my $passes = 0;
 	my $uk = defined($options{UK}) ? $options{UK} : 0;
 
@@ -157,7 +158,7 @@ sub parsedate
 				}
 			}
 			if (defined $M or defined $rd) {
-				if ($t =~ s/^\s*(?:at|\+)\s*(\s+|$)//x) {
+				if ($t =~ s/^\s*(?:at|\@|\+)\s*(\s+|$)//x) {
 					$rel = 1;
 					$parse .= " ".__LINE__ if $debug;
 					next;
@@ -391,7 +392,7 @@ sub mkoff
 {
 	my($offset) = @_;
 
-	if (defined $offset and $offset =~ s#^([-+])(\d\d)(\d\d)$##) {
+	if (defined $offset and $offset =~ s#^([-+])(\d\d):?(\d\d)$##) {
 		return ($1 eq '+' ? 
 			  3600 * $2  + 60 * $3
 			: -3600 * $2 + -60 * $3 );
@@ -407,7 +408,7 @@ sub parse_tz_only
 	my $o;
 
 	if ($$tr =~ s#^
-			([-+]\d\d\d\d)
+			([-+]\d\d:?\d\d)
 			\s+
 			\(
 				"?
@@ -430,7 +431,7 @@ sub parse_tz_only
 		return 1;
 	} elsif ($$tr =~ s#^GMT\s*([-+]\d{1,2})(\s+|$)##x) {
 		$o = $1;
-		if ($o <= 24 and $o !~ /^0/) {
+		if ($o < 24 and $o !~ /^0/) {
 			# probably hours.
 			printf "adjusted at %d. ($o 00)\n", __LINE__ if $debug;
 			$o = "${o}00";
@@ -439,14 +440,16 @@ sub parse_tz_only
 		$$tzo = &mkoff($o);
 		printf "matched at %d. ($$tzo, $o)\n", __LINE__ if $debug;
 		return 1;
-	} elsif ($$tr =~ s#^(?:GMT\s*)?([-+]\d\d\d\d)(\s+|$)##x) {
+	} elsif ($$tr =~ s#^(?:GMT\s*)?([-+]\d\d:?\d\d)(\s+|$)##x) {
 		$o = $1;
 		$$tzo = &mkoff($o);
 		printf "matched at %d.\n", __LINE__ if $debug;
 		return 1;
 	} elsif ($$tr =~ s#^"?((?:[A-Z]{1,4}[TCW56])|IDLE)(?:\s+|$ )##x) { #"
 		$$tz = $1;
-		printf "matched at %d.\n", __LINE__ if $debug;
+		$$tz .= " DST" 
+			if $$tz eq 'MET' && $$tr =~ s#^DST(?:\s+|$ )##x;
+		printf "matched at %d: '$$tz'.\n", __LINE__ if $debug;
 		return 1;
 	}
 	return 0;
@@ -458,7 +461,7 @@ sub parse_date_only
 
 	$$tr =~ s#^\s+##;
 
-	if ($$tr =~ s#^(\d\d\d\d)([-./])(\d\d?)\2(\d\d?)(\s+|$)##) {
+	if ($$tr =~ s#^(\d\d\d\d)([-./])(\d\d?)\2(\d\d?)(\s+|T|$)##) {
 		# yyyy/mm/dd
 
 		($$yr, $$mr, $$dr) = ($1, $3, $4);
@@ -671,7 +674,7 @@ sub parse_time_only
 						)?
 					)
 					\s*
-					([ap]m)?  		(?# $4)
+					([apAP][mM])?  		(?# $4)
 				) | (?:
 					(\d{1,2}) 		(?# $5)
 					(?:
@@ -682,7 +685,7 @@ sub parse_time_only
 							(\d\d)	(?# $7)
 								(
 									(?# don't barf on database sub-second timings)
-									(?:\:|\.)
+									[:.,]
 									\d{1,6}
 								)?	(?# $8)
 						)?
@@ -724,7 +727,6 @@ sub parse_time_only
 		$$tzr = $12;
 		$$hr += 12 if $ampm and "\U$ampm" eq "PM" && $$hr != 12;
 		$$hr = 0 if $$hr == 12 && "\U$ampm" eq "AM";
-		$$hr = 0 if $$hr == 24;
 		printf "matched at %d, rem = %s.\n", __LINE__, $$tr if $debug;
 		return 1;
 	} elsif ($$tr =~ s#noon(?:\s+|$ )##ix) {
@@ -1188,7 +1190,7 @@ Date parsing can also use options.  The options are as follows:
 
 =head2 Relative time formats:
 
-	count "minuts"
+	count "minutes"
 	count "seconds"
 	count "hours"
 	"+" count units
@@ -1221,7 +1223,7 @@ or undef if it was unable to parse the time.
 If a timezone is specified it must be after the time.  Year specifications
 can be tacked onto the end of absolute times.
 
-If C<parsedate()> is called from array contect, then it will return two
+If C<parsedate()> is called from array context, then it will return two
 elements.  On sucessful parses, it will return the seconds and what 
 remains of its input string.  On unsucessful parses, it will return
 C<undef> and an error string.
